package com.idea.customerManagement.service;

import cn.hutool.core.util.IdUtil;
import com.idea.buildManage.mapper.ParkFloorDiscMapper;
import com.idea.buildManage.mapper.ParkInfoMapper;
import com.idea.buildManage.model.ParkFloorDisc;
import com.idea.buildManage.model.ParkInfo;
import com.idea.buildManage.response.ParkRoomResponse;
import com.idea.customerManagement.mapper.CustomerManagementMapper;
import com.idea.customerManagement.mapper.IntentionalDepositMapper;
import com.idea.customerManagement.model.CustomerManagement;
import com.idea.customerManagement.model.IntentionalDeposit;
import com.idea.customerManagement.model.IntentionalDepositExample;
import com.idea.customerManagement.model.RoomSelectionInfoExample;
import com.rockstar.common.base.BaseService;
import com.rockstar.shiro.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class IntentionalDepositService implements BaseService<IntentionalDeposit, IntentionalDepositExample> {

    @Autowired
    private IntentionalDepositMapper modelMapper;
    @Autowired
    private CustomerManagementMapper customerManagementMapper;
    @Autowired
    private ParkInfoMapper parkInfoMapper;
    @Autowired
    private ParkFloorDiscMapper parkFloorDiscMapper;


    @Override
    public int deleteByPrimaryKey(String s) {
        return modelMapper.deleteByPrimaryKey(s);
    }

    @Override
    public int insertSelective(IntentionalDeposit intentionalDeposit) {
        intentionalDeposit.setId(IdUtil.simpleUUID());
        return modelMapper.insertSelective(intentionalDeposit);
    }

    public int insertWithoutId(IntentionalDeposit intentionalDeposit) {
        return modelMapper.insertSelective(intentionalDeposit);
    }

    @Override
    public IntentionalDeposit selectByPrimaryKey(String s) {
        return modelMapper.selectByPrimaryKey(s);
    }

    @Override
    public int updateByPrimaryKeySelective(IntentionalDeposit intentionalDeposit) {
        return modelMapper.updateByPrimaryKeySelective(intentionalDeposit);
    }

    @Override
    public int updateByExampleSelective(IntentionalDeposit intentionalDeposit, IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.updateByExampleSelective(intentionalDeposit,intentionalDepositExample);
    }

    @Override
    public int updateByExample(IntentionalDeposit intentionalDeposit, IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.updateByExample(intentionalDeposit,intentionalDepositExample);
    }

    @Override
    public List<IntentionalDeposit> selectByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.selectByExample(intentionalDepositExample);
    }

    @Override
    public long countByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.countByExample(intentionalDepositExample);
    }

    @Override
    public int deleteByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.deleteByExample(intentionalDepositExample);
    }

    /**
     * 获取收据流水号（意向金编号）
     * @param customerManagementId
     * @return
     */
    public String getSerialNumber(String customerManagementId){
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(customerManagementId);
        String groupId = customerManagement.getGroupId();
        String discId = customerManagement.getDiscId();
        // 查找这个小区已收取意向金的 数据量
        IntentionalDepositExample example = new IntentionalDepositExample();
        example.createCriteria().andGroupIdEqualTo(groupId);
        Long count = countByExample(example);
        String number = "";
        if(count.doubleValue() == 0){
            number = "00001";
        }else {
            count ++;
            number = String.format(count.toString(), "%05d", 1);
        }
        ParkInfo parkInfo = parkInfoMapper.selectByPrimaryKey(groupId);
        ParkFloorDisc parkFloorDisc = parkFloorDiscMapper.selectByPrimaryKey(discId);
        String serialNumber = parkInfo.getGroupName()+ parkFloorDisc.getName() + "YXJ" + number;
        return serialNumber;
    }

    /**
     * 意向金登记
     * @param model
     * @return
     */
    public int add(IntentionalDeposit model){

        model.setCreatedAt(new Date());
        model.setCreatedId(ShiroUtils.getUserId());
        return insertSelective(model);
    }





}
